OC.L10N.register(
    "files",
    {
    "File could not be found" : "O arquivo não foi encontrado",
    "Move or copy" : "Mover ou copiar",
    "Download" : "Baixar",
    "Delete" : "Excluir",
    "Tags" : "Etiquetas",
    "Show list view" : "Mostrar visualização em lista",
    "Show grid view" : "Mostrar visualização em grade",
    "Home" : "Início",
    "Close" : "Fechar",
    "Could not create folder \"{dir}\"" : "Não foi possível criar a pasta \"{dir}\"",
    "This will stop your current uploads." : "Isso irá parar seus envios atuais.",
    "Upload cancelled." : "Envio cancelado.",
    "Processing files …" : "Processando arquivos...",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Não foi possível fazer o envio de {filename}, pois é um diretório ou tem 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Não há espaço suficiente, você está enviando {size1} mas resta apenas {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Pasta de destino \"{dir}\" não existe mais",
    "Not enough free space" : "Espaço livre insuficiente",
    "An unknown error has occurred" : "Um erro desconhecido ocorreu",
    "File could not be uploaded" : "Não foi possível enviar o arquivo",
    "Uploading …" : "Enviando...",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Enviando … ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "O envio deste item não é suportado",
    "Target folder does not exist any more" : "Pasta destino não existe mais",
    "Operation is blocked by access control" : "A operação está bloqueada pelo controle de acesso",
    "Error when assembling chunks, status code {status}" : "Erro ao montar partes, código de status {status}",
    "Actions" : "Ações",
    "Rename" : "Renomear",
    "Move" : "Mover",
    "Copy" : "Copiar",
    "Choose target folder" : "Escolher pasta destino",
    "Set reminder" : "Definir lembrete",
    "Edit locally" : "Editar localmente",
    "Open" : "Abrir",
    "Delete file" : "Deletar arquivo",
    "Delete folder" : "Excluir pasta",
    "Disconnect storage" : "Desconectar armazenamento",
    "Leave this share" : "Deixe esses compartilhamentos",
    "Could not load info for file \"{file}\"" : "Não foi possível carregar informações para o arquivo \"{file}\" ",
    "Files" : "Arquivos",
    "Details" : "Detalhes",
    "Please select tag(s) to add to the selection" : "Selecione a(s) etiquetas(s) para adicionar à seleção ",
    "Apply tag(s) to selection" : "Aplicar as etiqueta(s) a seleção",
    "Select directory \"{dirName}\"" : "Selecione o diretório \"{dirName}\"",
    "Select file \"{fileName}\"" : "Selecione o arquivo \"{fileName}\"",
    "Pending" : "Pendente",
    "Unable to determine date" : "Impossível determinar a data",
    "This operation is forbidden" : "Esta operação é proibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Este diretório não está disponível, por favor verifique os logs ou contacte o administrador",
    "Storage is temporarily not available" : "O armazenamento está temporariamente indisponível",
    "Could not move \"{file}\", target exists" : "Não foi possível mover \"{file}\" pois o destino já existe",
    "Could not move \"{file}\"" : "Não foi possível mover \"{file}\"",
    "copy" : "copiar",
    "Could not copy \"{file}\", target exists" : "Não foi possível copiar \"{file}\", pois já existe",
    "Could not copy \"{file}\"" : "Não foi possível copiar \"{file}\"",
    "Copied {origin} inside {destination}" : "{origin} foi copiado para {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} e outros {nbfiles} arquivos foram copiados para {destination}",
    "Failed to redirect to client" : "Falha ao redirecionar para o cliente",
    "{newName} already exists" : "{newName} já existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "Não foi possível renomear \"{fileName}\" pois ele não existe mais",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{targetName}\" já está sendo usado na pasta  \"{dir}\". Por favor escolha um nome diferente.",
    "Could not rename \"{fileName}\"" : "Não foi possível renomear \"{fileName}\"",
    "Could not create file \"{file}\"" : "Não foi possível criar o arquivo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Não foi possível criar o arquivo \"{file}\" pois ele já existe",
    "Could not create folder \"{dir}\" because it already exists" : "Não foi possível criar a pasta \"{dir}\" pois ela já existe",
    "Could not fetch file details \"{file}\"" : "Não foi possível buscar os detalhes do arquivo \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Ocorreu um erro ao excluir o arquivo \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Sem resultados de pesquisa em outras pastas para {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Digite mais de dois caracteres para pesquisar em outras pastas",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas","%n pastas"],
    "_%n file_::_%n files_" : ["%n arquivo","%n arquivos","%n arquivos"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluindo %n oculto","incluindo %n ocultos","incluindo %n ocultos"],
    "You do not have permission to upload or create files here" : "Você não tem permissão para upload ou criar arquivos aqui",
    "_Uploading %n file_::_Uploading %n files_" : ["Enviando %n arquivo","Enviando %n arquivos","Enviando %n arquivos"],
    "New" : "Novo",
    "New file/folder menu" : "Novo menu de arquivo/pasta",
    "Select file range" : "Selecionar o intervalo de arquivos",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "{used} de {quota} usados",
    "{used} used" : "{used} usados",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de arquivo inválido.",
    "File name cannot be empty." : "O nome do arquivo não pode estar em branco.",
    "\"/\" is not allowed inside a file name." : "\"/\" não é permitido no nome do arquivo.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" não é um tipo de arquivo permitido",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "O armazenamento do {owner} está cheio, os arquivos não podem ser enviados ou sincronizados.",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "A pasta do grupo \"{mountPoint}\" está cheia, os arquivos não podem ser enviados ou sincronizados.",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "O armazenamento externo \"{mountPoint}\" está cheio, os arquivos não podem ser enviados ou sincronizados.",
    "Your storage is full, files cannot be updated or synced anymore!" : "Seu armazenamento está cheio, os arquivos não podem ser enviados ou sincronizados.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "O armazenamento do {owner} está quase cheio ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "A pasta de grupo \"{mountPoint}\" está quase cheia ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "O armazenamento externo \"{mountPoint}\" está quase cheio ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Seu armazenamento está quase cheio ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coincide \"{filter}\"","coincide \"{filter}\"","coincide \"{filter}\""],
    "View in folder" : "Exibir na pasta",
    "Direct link was copied (only works for people who have access to this file/folder)" : "Link direto foi copiado (funciona apenas para pessoas que têm acesso a este arquivo/pasta)",
    "Path" : "Caminho",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
    "Favorited" : "Favoritado",
    "Favorite" : "Favorito",
    "Copy direct link (only works for people who have access to this file/folder)" : "Copiar link direto (funciona apenas para pessoas que têm acesso a este arquivo/pasta)",
    "New folder" : "Nova pasta",
    "Create new folder" : "Criar nova pasta",
    "Upload file" : "Enviar arquivo",
    "Recent" : "Recentes",
    "Not favorited" : "Sem favoritos",
    "Remove from favorites" : "Excluir dos favoritos",
    "Add to favorites" : "Adicionar aos favoritos",
    "An error occurred while trying to update the tags" : "Ocorreu um erro enquanto tentava atualizar as etiquetas",
    "Added to favorites" : "Adicionado aos favoritos",
    "Removed from favorites" : "Removido dos favoritos",
    "You added {file} to your favorites" : "Você adicionou {file} aos seus favoritos",
    "You removed {file} from your favorites" : "Você excluiu {file} dos seus favoritos",
    "Favorites" : "Favoritos",
    "File changes" : "Mudanças nos arquivos",
    "Created by {user}" : "Criado por {user}",
    "Changed by {user}" : "Modificado por {user}",
    "Deleted by {user}" : "Apagado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renomeado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote account\"" : "\"conta remota\"",
    "You created {file}" : "Você criou {file}",
    "You created an encrypted file in {file}" : "Você criou um arquivo criptografado em {file}",
    "{user} created {file}" : "{user} criou {file}",
    "{user} created an encrypted file in {file}" : "{user} criou um arquivo criptografado em {file}",
    "{file} was created in a public folder" : "O arquivo {file} foi criado em uma pasta pública",
    "You changed {file}" : "Você modificou o arquivo {file}",
    "You changed an encrypted file in {file}" : "Você alterou um arquivo criptografado em {file}",
    "{user} changed {file}" : "{user} modificou {file}",
    "{user} changed an encrypted file in {file}" : "{user} alterou um arquivo criptografado em {file}",
    "You deleted {file}" : "Você excluiu {file}",
    "You deleted an encrypted file in {file}" : "Você excluiu um arquivo criptografado em {file}",
    "{user} deleted {file}" : "{user} excluiu o arquivo {file}",
    "{user} deleted an encrypted file in {file}" : "{user} excluiu um arquivo criptografado em {file}",
    "You restored {file}" : "Você restaurou o arquivo {file}",
    "{user} restored {file}" : "{user} restaurou {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Você renomeou {oldfile} (oculto) para {newfile} (oculto)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Você renomeou {oldfile} (oculto) para {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Você renomeou {oldfile} para {newfile} (oculto)",
    "You renamed {oldfile} to {newfile}" : "Você renomeou o arquivo {oldfile} para {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} renomeou {oldfile} (oculto) para {newfile} (oculto)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} renomeou {oldfile} (oculto) para {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} renomeou {oldfile} para {newfile} (oculto)",
    "{user} renamed {oldfile} to {newfile}" : "{user} renomeou {oldfile} para {newfile}",
    "You moved {oldfile} to {newfile}" : "Você moveu {oldfile} para {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moveu {oldfile} para {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Um arquivo foi adicionado ou removido de seus <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong>" : "Um arquivo ou pasta foi <strong>modificado</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Um arquivo ou pasta favorita foi <strong>modificado</strong>",
    "Failed to authorize" : "Falha ao autorizar",
    "Invalid folder path" : "Caminho de pasta inválido",
    "Folder not found" : "Pasta não encontrada",
    "Upload (max. %s)" : "Envio (max. %s)",
    "Files compatibility" : "Compatibilidade de arquivos",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permitir restringir nomes de arquivos para garantir que os arquivos possam ser sincronizados com todos os clientes. Por padrão, todos os nomes de arquivos válidos em POSIX (por exemplo, Linux ou macOS) são permitidos.",
    "Enforce Windows compatibility" : "Aplicar compatibilidade do Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Isso bloqueará nomes de arquivos não válidos em sistemas Windows, como nomes reservados ou caracteres especiais. Mas isso não imporá a compatibilidade da distinção entre maiúsculas e minúsculas.",
    "Accept" : "Aceitar",
    "Reject" : "Rejeitar",
    "Incoming ownership transfer from {user}" : "Transferência de propriedade recebida de {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Deseja aceitar {path}?\n\nObservação: O processo de transferência pode levar até 1 hora.",
    "Ownership transfer denied" : "Transferência de propriedade negada",
    "Your ownership transfer of {path} was denied by {user}." : "Sua transferência de propriedade de {caminho} foi negado por {usuário}.",
    "Ownership transfer failed" : "Erro na transferência da propriedade",
    "Your ownership transfer of {path} to {user} failed." : "Erro na transferência da sua propriedade de {path} para {user}.",
    "The ownership transfer of {path} from {user} failed." : "Erro na transferência da propriedade de {path} de {user}.",
    "Ownership transfer done" : "A transferência da propriedade foi finalizada",
    "Your ownership transfer of {path} to {user} has completed." : "A transferência da sua propriedade de {path} para {user} foi concluída.",
    "The ownership transfer of {path} from {user} has completed." : "A transferência da propriedade de {path} de {user} foi concluída.",
    "in %s" : "em %s",
    "Transferred from %1$s on %2$s" : "Transferido de %1$s para %2$s",
    "File Management" : "Gerenciamento de Arquivos",
    "Current directory path" : "Caminho do diretório atual",
    "Reload current directory" : "Recarregar diretório atual",
    "Go to the \"{dir}\" directory" : "Vá para o diretório \"{dir}\"",
    "Drag and drop files here to upload" : "Arraste e solte os arquivos aqui para fazer upload",
    "Your have used your space quota and cannot upload files anymore" : "Você usou sua cota de espaço e não pode mais fazer upload de arquivos",
    "You don’t have permission to upload or create files here" : "Você não tem permissão para enviar ou criar arquivos aqui",
    "\"{displayName}\" action executed successfully" : "Ação \"{displayName}\" executada com sucesso",
    "\"{displayName}\" action failed" : "A ação \"{displayName}\" falhou",
    "Toggle selection for file \"{displayName}\"" : "Alternar seleção do arquivo \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Alternar seleção da pasta \"{displayName}\"",
    "File is loading" : "O arquivo está carregando",
    "Folder is loading" : "A pasta está carregando",
    "Rename file" : "Renomear arquivo",
    "Filename" : "Nome do arquivo",
    "Folder name" : "Nome da pasta",
    "This node is unavailable" : "Este nó está indisponível",
    "Another entry with the same name already exists." : "Outra entrada com o mesmo nome já existe.",
    "Invalid filename." : "Nome de arquivo inválido.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Renomeado de \"{oldName}\" para \"{newName}\"",
    "Could not rename \"{oldName}\", it does not exist any more" : "Não foi possível renomear \"{oldName}\", ele não existe mais",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{newName}\" já é utilizado na pasta \"{dir}\". Escolha um nome diferente.",
    "Could not rename \"{oldName}\"" : "Não foi possível renomear \"{oldName}\"",
    "Clear filter" : "Limpar filtro",
    "Type" : "Tipo",
    "Active filters" : "Filtros ativos",
    "Remove filter" : "Remover filtro",
    "Total rows summary" : "Resumo total de linhas",
    "Toggle selection for all files and folders" : "Alternar seleção para todos os arquivos e pastas",
    "\"{displayName}\" failed on some elements " : "\"{displayName}\" falhou em alguns elementos",
    "\"{displayName}\" batch action executed successfully" : "Ação em lote \"{displayName}\" executada com sucesso",
    "{count} selected" : "{count} selecionados",
    "List of files and folders." : "Lista de arquivos e pastas.",
    "Column headers with buttons are sortable." : "Os cabeçalhos das colunas com botões são classificáveis.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Essa lista não é totalmente renderizada por motivos de desempenho. Os arquivos serão renderizados conforme você navega pela lista.",
    "File not found" : "Arquivo não encontrado",
    "Storage information" : "Informações do armazenamento",
    "Storage quota" : "Quantidade de armazenamento",
    "{usedQuotaByte} used" : "{usedQuotaByte} usado",
    "{relative}% used" : "{relative}% usado",
    "Could not refresh storage stats" : "Não foi possível atualizar as estatísticas de armazenamento",
    "Your storage is full, files can not be updated or synced anymore!" : "Seu armazenamento está cheio e arquivos não podem mais ser atualizados ou sincronizados!",
    "Create" : "Criar",
    "This name is already in use." : "Este nome já está em uso.",
    "Fill template fields" : "Preencher campos do template",
    "Submitting fields…" : "Enviando arquivos…",
    "Submit" : "Enviar",
    "Transfer ownership of a file or folder" : "Transferir a propriedade de um arquivo ou pasta",
    "Choose file or folder to transfer" : "Escolha o arquivo ou pasta a transferir",
    "Change" : "Mudar",
    "New owner" : "Novo proprietário",
    "Choose a file or folder to transfer" : "Escolha o arquivo ou pasta a transferir",
    "Transfer" : "Transferir",
    "Transfer {path} to {userid}" : "Transferir {path} para {userid}",
    "Invalid path selected" : "Caminho inválido selecionado",
    "Unknown error" : "Erro desconhecido",
    "Ownership transfer request sent" : "Solicitação de transferência de propriedade enviada",
    "Cannot transfer ownership of a file or folder you do not own" : "Não é possível transferir a propriedade de um arquivo ou pasta que você não possui",
    "Select file or folder to link to" : "Selecione o arquivo ou pasta para vincular",
    "Choose file" : "Escolher arquivo",
    "Choose {file}" : "Escolher {file}",
    "Loading current folder" : "Carregando a pasta atual",
    "No files in here" : "Nenhum arquivo aqui",
    "Upload some content or sync with your devices!" : "Envie um arquivo ou sincronize com seus dispositivos!",
    "Go to the previous folder" : "Ir para a pasta anterior",
    "Go back" : "Voltar",
    "Share" : "Compartilhar",
    "Shared by link" : "Compartilhado via link",
    "Shared" : "Compartilhado",
    "Switch to list view" : "Mudar para a visualizar lista",
    "Switch to grid view" : "Mudar para visualização em grade",
    "Upload was cancelled by user" : "O upload foi cancelado pelo usuário",
    "Error during upload: {message}" : "Erro durante o upload: {message}",
    "Error during upload, status code {status}" : "Erro durante o upload, código de status {status}",
    "Unknown error during upload" : "Erro desconhecido durante o upload",
    "Filter filenames…" : "Filtrar nomes de arquivos...",
    "Views" : "Visualizações",
    "Files settings" : "Configurações de arquivos",
    "File cannot be accessed" : "File cannot be accessed",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "O arquivo não foi encontrado ou você não tem permissão para visualizá-lo. Peça ao remetente para compartilhá-lo.",
    "Your files" : "Seus arquivos",
    "Open in files" : "Abrir em arquivos",
    "Sort favorites first" : "Ordenar favoritos primeiro",
    "Sort folders before files" : "Classifique as pastas antes dos arquivos",
    "Show hidden files" : "Mostrar arquivos ocultos",
    "Crop image previews" : "Cortar visualizações de imagem",
    "Enable the grid view" : "Habilite a visualização em grade",
    "Enable folder tree" : "Habilitar árvore de pastas",
    "Additional settings" : "Configurações adicionais",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV URL",
    "Copy to clipboard" : "Copiar para área de transferência",
    "Use this address to access your Files via WebDAV" : "Use este endereço para acessar seus Arquivos via WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "If you have enabled 2FA, you must create and use a new app password by clicking here.",
    "Clipboard is not available" : "A área de transferência não está disponível",
    "WebDAV URL copied to clipboard" : "URL do WebDAV copiado para a área de transferência",
    "Unable to change the favourite state of the file" : "Não foi possível alterar o estado favorito do arquivo",
    "Error while loading the file data" : "Erro ao carregar os dados do arquivo",
    "Pick a template for {name}" : "Escolha um modelo para {name}",
    "Create a new file with the selected template" : "Crie um novo arquivo com o modelo selecionado",
    "Creating file" : "Criando arquivo",
    "Blank" : "Em branco",
    "Unable to create new file from template" : "Incapaz de criar novo arquivo a partir do modelo",
    "Deletion cancelled" : "Operação de exclusão cancelada",
    "Delete permanently" : "Remover permanentemente",
    "Delete and unshare" : "Excluir e descompartilhar",
    "Leave these shares" : "Deixe esses compartilhamentos",
    "Disconnect storages" : "Desconectar armazenamentos",
    "Delete files" : "Deletar arquivos",
    "Delete folders" : "Excluir pastas",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Você está prestes a excluir permanentemente {count} itens","Você está prestes a excluir permanentemente {count} itens","Você está prestes a excluir permanentemente {count} itens"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Você está prestes a excluir {count} itens","Você está prestes a excluir {count} itens","Você está prestes a excluir {count} itens"],
    "Confirm deletion" : "Confirmar exclusão",
    "Cancel" : "Cancelar",
    "Edit file locally" : "Editar arquivo localmente",
    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "O arquivo agora deve abrir localmente. Se isso não acontecer, certifique-se de que o cliente de desktop esteja instalado em seu sistema.",
    "Retry local edit" : "Tentar novamente a edição local",
    "Edit online" : "Editar on-line",
    "Destination is not a folder" : "O destino não é uma pasta",
    "This file/folder is already in that directory" : "Este arquivo/pasta já está nesse diretório",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Você não pode mover um arquivo/pasta para si mesmo ou para uma subpasta dele mesmo",
    "(copy)" : "(cópia)",
    "(copy %n)" : "(copiar %n)",
    "Move cancelled" : "Movimento cancelado",
    "A file or folder with that name already exists in this folder" : "Já existe um arquivo ou pasta com esse nome nesta pasta",
    "The files are locked" : "Os arquivos estão bloqueados",
    "The file does not exist anymore" : "O arquivo não existe mais",
    "Choose destination" : "Escolha o destino",
    "Copy to {target}" : "Copiar para {target}",
    "Move to {target}" : "Mover para {target}",
    "Move or copy operation failed" : "Falha na operação de movimentação ou cópia",
    "Cancelled move or copy of \"{filename}\"." : "Movimiento cancelado o copia de \"{filename}\".",
    "Cancelled move or copy operation" : "Operação de movimentação ou cópia cancelada",
    "Open folder {displayName}" : "Abra a pasta {displayName}",
    "Open in Files" : "Abrir em arquivos",
    "Open details" : "Abrir detalhes",
    "Today" : "Hoje",
    "Last 7 days" : "Últimos 7 dias",
    "Last 30 days" : "Últimos 30 dias",
    "This year ({year})" : "Este ano ({year})",
    "Last year ({year})" : "Ano passado  ({year})",
    "Documents" : "Documentos",
    "Spreadsheets" : "Planilhas",
    "Presentations" : "Apresentações",
    "PDFs" : "PDFs",
    "Folders" : "Pastas",
    "Audio" : "Áudio",
    "Photos and images" : "Fotos e imagens",
    "Videos" : "Vídeos",
    "New folder creation cancelled" : "Criação de nova pasta cancelada",
    "Created new folder \"{name}\"" : "Nova pasta criada \"{name}\"",
    "Unable to initialize the templates directory" : "Não foi possível inicializar o diretório de modelos",
    "Create templates folder" : "Criar pasta de modelos",
    "Templates" : "Modelos",
    "New template folder" : "Nova pasta de modelo",
    "In folder" : "Na pasta",
    "Search in folder: {folder}" : "Pesquisar na pasta: {folder}",
    "One of the dropped files could not be processed" : "Um dos arquivos descartados não pôde ser processado",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Seu navegador não oferece suporte à API Filesystem. Os diretórios não serão carregados",
    "No files to upload" : "Não há arquivos para enviar",
    "Unable to create the directory {directory}" : "Não foi possível criar o diretório {directory}",
    "Some files could not be uploaded" : "Alguns arquivos não puderam ser carregados",
    "Files uploaded successfully" : "Arquivos enviados com sucesso",
    "No files to process" : "Nenhum arquivo para processar",
    "Some files could not be copied" : "Alguns arquivos não puderam ser copiados",
    "Some files could not be moved" : "Alguns arquivos não puderam ser movidos",
    "Files copied successfully" : "Arquivos copiados com sucesso",
    "Files moved successfully" : "Arquivos movidos com sucesso",
    "Conflicts resolution skipped" : "Resolução de conflitos ignorada",
    "Upload cancelled" : "Carregamento cancelado",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} pastas","{folderCount} pastas","{folderCount} pastas"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} arquivos","{fileCount} arquivos","{fileCount} arquivos"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 arquivo e {folderCount} pastas","1 arquivo e {folderCount} pastas","1 arquivo e {folderCount} pastas"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} arquivos e 1 pasta","{fileCount} arquivos e 1 pasta","{fileCount} arquivos e 1 pasta"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} arquivos e {folderCount} pastas",
    "Filename must not be empty." : "O nome do arquivo não pode estar vazio.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" não é permitido dentro de um nome de arquivo.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" é um nome reservado e não é permitido para nomes de arquivos.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" não é um tipo de arquivo permitido.",
    "Filenames must not end with \"{extension}\"." : "Os nomes de arquivos não podem terminar com \"{extension}\".",
    "List of favorites files and folders." : "Lista de arquivos e pastas favoritos.",
    "No favorites yet" : "Você não possui favoritos!",
    "Files and folders you mark as favorite will show up here" : "Suas pastas e arquivos favoritos serão exibidos aqui.",
    "All files" : "Todos os arquivos",
    "List of your files and folders." : "Lista de seus arquivos e pastas.",
    "All folders" : "Todas as pastas",
    "Personal Files" : "Arquivos pessoais",
    "List of your files and folders that are not shared." : "Lista dos seus arquivos e pastas que não estão compartilhados.",
    "No personal files found" : "Nenhum arquivo pessoal encontrado",
    "Files that are not shared will show up here." : "Arquivos que não estão compartilhados aparecerão aqui.",
    "List of recently modified files and folders." : "Lista de arquivos e pastas modificados recentemente.",
    "No recently modified files" : "Nenhum arquivo modificado recentemente",
    "Files and folders you recently modified will show up here." : "Arquivos e pastas que você modificou recentemente aparecerão aqui.",
    "No entries found in this folder" : "Nenhuma entrada foi encontrada nesta pasta",
    "Select all" : "Selecionar tudo",
    "Upload too large" : "Arquivo muito grande para envio",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os arquivos que você está tentando enviar excederam o tamanho máximo para arquivos no servidor.",
    "Text file" : "Arquivo texto",
    "New text file.txt" : "Novo arquivo de texto arquivo.txt",
    "Direct link was copied (only works for users who have access to this file/folder)" : "O link direto foi copiado (funciona apenas para usuários que têm acesso a este arquivo/pasta)",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar link direto (funciona apenas para usuários que tem acesso a este arquivo/pasta)",
    "\"remote user\"" : "\"usuário remoto\"",
    "{newName} already exists." : "{newName} já existe.",
    "\"{segment}\" is not allowed inside a filename." : "\"{segment}\" não é permitido dentro de um nome de arquivo.",
    "\"{segment}\" is a forbidden file or folder name." : "\"{segment}\" é um nome de arquivo ou pasta proibido.",
    "\"{segment}\" is not an allowed filetype." : "\"{segment}\" não é um tipo de arquivo permitido.",
    "Filenames must not end with \"{segment}\"." : "Os nomes de arquivos não devem terminar com \"{segment}\".",
    "Name cannot be empty" : "O nome não pode ficar em branco",
    "Another entry with the same name already exists" : "Já existe outra entrada com o mesmo nome",
    "Storage informations" : "Informações de armazenamento",
    "Open the files app settings" : "Abra as configurações do aplicativo de arquivos",
    "You might not have have permissions to view it, ask the sender to share it" : "You might not have have permissions to view it, ask the sender to share it",
    "The files is locked" : "Os arquivos estão bloqueados",
    "Create new templates folder" : "Criar nova pasta de modelos",
    "Toggle %1$s sublist" : "Alternar a sublista %1$s"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
